@@ -238,10 +238,6 @@ class BaseXMPP(XMLStream):
             log.warning('Legacy XMPP 0.9 protocol detected.')
             self.event('legacy_protocol')
 
-    def process(self, *, forever=True, timeout=None):
-        self.init_plugins()
-        XMLStream.process(self, forever=forever, timeout=timeout)
-
     def init_plugins(self):
         for name in self.plugin:
             if not hasattr(self.plugin[name], 'post_inited'):
@@ -315,13 +311,12 @@ class BaseXMPP(XMLStream):
         pres['lang'] = self.default_lang
         return pres
 
-    def make_iq(self, id: str = "0", ifrom: OptJidStr = None,
+    def make_iq(self, id: Optional[str] = None, ifrom: OptJidStr = None,
                 ito: OptJidStr = None, itype: Optional[IqTypes] = None,
                 iquery: Optional[str] = None) -> stanza.Iq:
         """Create a new :class:`~.Iq` stanza with a given Id and from JID.
 
         :param id: An ideally unique ID value for this stanza thread.
-                   Defaults to 0.
         :param ifrom: The from :class:`~.JID`
                       to use for this stanza.
         :param ito: The destination :class:`~.JID`
@@ -332,7 +327,8 @@ class BaseXMPP(XMLStream):
         :param iquery: Optional namespace for adding a query element.
         """
         iq = self.Iq()
-        iq['id'] = str(id)
+        if id is not None:
+            iq['id'] = str(id)
         iq['to'] = ito
         iq['from'] = ifrom
         iq['type'] = itype
@@ -837,11 +833,11 @@ class BaseXMPP(XMLStream):
             iq = exception.iq
             log.error('%s: %s', iq['error']['condition'],
                                 iq['error']['text'])
-            log.warning('You should catch IqError exceptions')
+            log.warning('You should catch IqError exceptions', exc_info=True)
         elif isinstance(exception, IqTimeout):
             iq = exception.iq
             log.error('Request timed out: %s', iq)
-            log.warning('You should catch IqTimeout exceptions')
+            log.warning('You should catch IqTimeout exceptions', exc_info=True)
         elif isinstance(exception, SyntaxError):
             # Hide stream parsing errors that occur when the
             # stream is disconnected (they've been handled, we
