@@ -109,6 +109,7 @@ PLUGINS = [
     'xep_0403',  # MIX-Presence
     'xep_0404',  # MIX-Anon
     'xep_0405',  # MIX-PAM
+    'xep_0410',  # MUC Self-ping
     'xep_0421',  # Anonymous unique occupant identifiers for MUCs
     'xep_0422',  # Message Fastening
     'xep_0424',  # Message Retraction
@@ -118,10 +119,13 @@ PLUGINS = [
     'xep_0439',  # Quick Response
     'xep_0441',  # Message Archive Management Preferences
     'xep_0444',  # Message Reactions
+    'xep_0446',  # File metadata element
     'xep_0447',  # Stateless file sharing
     'xep_0461',  # Message Replies
     'xep_0469',  # Bookmarks Pinning
+    'xep_0482',  # Call Invites
     'xep_0490',  # Message Displayed Synchronization
+    'xep_0492',  # Chat Notification Settings
     # Meant to be imported by plugins
 ]
 
