@@ -281,7 +281,8 @@ class XMLStream(asyncio.BaseProtocol):
     __slow_tasks: List[Task]
     __queued_stanzas: List[Tuple[Union[StanzaBase, str], bool]]
 
-    def __init__(self, host: str = '', port: int = 0):
+    def __init__(self, host: str = '', port: int = 0,
+                 ssl_context: Optional[ssl.SSLContext] = None):
         self.transport = None
         self.socket = None
         self._connect_loop_wait = 0
@@ -298,9 +299,12 @@ class XMLStream(asyncio.BaseProtocol):
         # A dict of {name: handle}
         self.scheduled_events = {}
 
-        self.ssl_context = ssl.create_default_context()
-        self.ssl_context.check_hostname = True
-        self.ssl_context.verify_mode = ssl.CERT_REQUIRED
+        if ssl_context is None:
+            self.ssl_context = ssl.create_default_context()
+            self.ssl_context.check_hostname = True
+            self.ssl_context.verify_mode = ssl.CERT_REQUIRED
+        else:
+            self.ssl_context = ssl_context
 
         self.event_when_connected = "connected"
 
@@ -371,7 +375,22 @@ class XMLStream(asyncio.BaseProtocol):
     @property
     def loop(self) -> AbstractEventLoop:
         if self._loop is None:
-            self._loop = asyncio.get_event_loop()
+            try:
+                # Python < 3.14
+                with warnings.catch_warnings():
+                    warnings.simplefilter("ignore")
+                    self._loop = asyncio.get_event_loop()
+            except RuntimeError:
+                try:
+                    current = asyncio.get_running_loop()
+                except RuntimeError:
+                    current = None
+                if current is not None:
+                    self._loop = current
+                else:
+                    loop = asyncio.new_event_loop()
+                    asyncio.set_event_loop(loop)
+                    self._loop = loop
         return self._loop
 
     @loop.setter
@@ -405,9 +424,10 @@ class XMLStream(asyncio.BaseProtocol):
             self.disconnected.set_result(True)
         self.disconnected = asyncio.Future()
 
-    def connect(self, host: str = '', port: int = 0, use_ssl: Optional[bool] = None,
+    def connect(self, host: str = '', port: int = 0,
+                use_ssl: Optional[bool] = None,
                 force_starttls: Optional[bool] = None,
-                disable_starttls: Optional[bool] = None) -> None:
+                disable_starttls: Optional[bool] = None) -> asyncio.Future:
         """Create a new socket and connect to the server.
 
         :param host: The name of the desired server for the connection.
@@ -426,6 +446,7 @@ class XMLStream(asyncio.BaseProtocol):
                                upgrade to TLS, even if the server provides
                                it.  Use this for example if you’re on
                                localhost
+        :returns: A future on the current connection attempt
 
         """
         if self._run_out_filters is None or self._run_out_filters.done():
@@ -457,8 +478,14 @@ class XMLStream(asyncio.BaseProtocol):
             self._connect_routine(),
             loop=self.loop,
         )
+        return self._current_connection_attempt
 
-    async def _connect_routine(self) -> None:
+    async def _connect_routine(self) -> Optional[asyncio.Future]:
+        """
+        Returns None if the attempt was canceled or if the connection succeeded
+        (cancelling done manually by the library user, so that should be known)
+        or the next connection attempt future if a new try has been scheduled.
+        """
         self.event_when_connected = "connected"
 
         if self._connect_loop_wait > 0:
@@ -483,7 +510,7 @@ class XMLStream(asyncio.BaseProtocol):
             ssl_context = None
 
         if self._current_connection_attempt is None:
-            return
+            return None
         try:
             server_hostname = self.default_domain if self.use_ssl else None
             await self.loop.create_connection(lambda: self,
@@ -495,39 +522,12 @@ class XMLStream(asyncio.BaseProtocol):
         except Socket.gaierror as e:
             self.event('connection_failed',
                        'No DNS record available for %s' % self.default_domain)
-            self.reschedule_connection_attempt()
+            return self.reschedule_connection_attempt()
         except OSError as e:
             log.debug('Connection failed: %s', e)
             self.event("connection_failed", e)
-            self.reschedule_connection_attempt()
-
-    def process(self, *, forever: bool = True, timeout: Optional[int] = None) -> None:
-        """Process all the available XMPP events (receiving or sending data on the
-        socket(s), calling various registered callbacks, calling expired
-        timers, handling signal events, etc).  If timeout is None, this
-        function will run forever. If timeout is a number, this function
-        will return after the given time in seconds.
-
-        Will be removed in slixmpp 1.9.0
-
-        :deprecated: 1.8.0
-        """
-        warnings.warn(
-            'This function will be removed in slixmpp 1.9 and above.'
-            ' Use the asyncio normal functions instead.',
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
-        if timeout is None:
-            if forever:
-                self.loop.run_forever()
-            else:
-                self.loop.run_until_complete(self.disconnected)
-        else:
-            tasks: List[Union[asyncio.Task, asyncio.Future]] = [asyncio.Task(asyncio.sleep(timeout))]
-            if not forever:
-                tasks.append(self.disconnected)
-            self.loop.run_until_complete(asyncio.wait(tasks))
+            return self.reschedule_connection_attempt()
+        return None
 
     def init_parser(self) -> None:
         """init the XML parser. The parser must always be reset for each new
@@ -635,19 +635,22 @@ class XMLStream(asyncio.BaseProtocol):
         self._set_disconnected_future()
         self.event("disconnected", self.disconnect_reason or exception)
 
-    def reschedule_connection_attempt(self) -> None:
+    def reschedule_connection_attempt(self) -> Optional[asyncio.Future]:
         """
         Increase the exponential back-off and initate another background
         _connect_routine call to connect to the server.
+
+        :returns: A future on the next scheduled connection attempt.
         """
         # abort if there is no ongoing connection attempt
         if self._current_connection_attempt is None:
-            return
+            return None
         self._connect_loop_wait = min(300, self._connect_loop_wait * 2 + 1)
         self._current_connection_attempt = asyncio.ensure_future(
             self._connect_routine(),
             loop=self.loop,
         )
+        return self._current_connection_attempt
 
     def cancel_connection_attempt(self) -> None:
         """
